eqzUI: UI for the Shiny Tanner crab equilibrium size distribution...

Description Usage Arguments Details Value

View source: R/eqzUI.R

Description

Function to create the UI for the Shiny Tanner crab equilibrium size distribution module.

Usage

1
eqzUI(id)

Arguments

id

- a character string that uniquely identifies the equilibrium size distribution module in the enclosing Shiny UI.

Details

Allows the user to change the equilibrium size distribution parameters and plot the results for the Tanner crab model.

Value

A Shiny tabPanel allowing the user to change the equilibrium size distribution parameters and plot the results.


wStockhausen/shinyTC.CohortProgression documentation built on July 19, 2021, 5:32 a.m.