moltUI: UI for the Shiny Tanner crab probability of molt module

Description Usage Arguments Details Value

View source: R/moltUI.R

Description

Function to create the UI for the Shiny Tanner crab probability of molt module.

Usage

1
moltUI(id)

Arguments

id

- a character string that uniquely identifies the probability of molt module in the enclosing Shiny UI.

Details

Allows the user to change probability of molt parameters and plot probabilities of molt for the Tanner crab model.

Value

A Shiny tabPanel allowing the user to change probability of molt parameters and plot probabilities of molt.


wStockhausen/shinyTC.CohortProgression documentation built on July 19, 2021, 5:32 a.m.