Description Usage Arguments Details Value
Function to create the UI for the Shiny Tanner crab equilibrium size distribution module.
1 | eqzUI(id)
|
id |
- a character string that uniquely identifies the equilibrium size distribution module in the enclosing Shiny UI. |
Allows the user to change the equilibrium size distribution parameters and plot the results for the Tanner crab model.
A Shiny tabPanel allowing the user to change the equilibrium size distribution parameters and plot the results.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.