Description Usage Arguments Details Value
Function to create the UI for the Shiny Tanner crab probability of molt module.
1 | moltUI(id)
|
id |
- a character string that uniquely identifies the probability of molt module in the enclosing Shiny UI. |
Allows the user to change probability of molt parameters and plot probabilities of molt for the Tanner crab model.
A Shiny tabPanel allowing the user to change probability of molt parameters and plot probabilities of molt.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.